@@ -16,10 +16,12 @@ class newpage: # The VERY base class in Ebuilder Ultra Core, This handles all th
     <meta name="viewport" content="width=device-width">
     <title>{title}</title>
   </head>
-  <body>
-  """)
+  <body>""")
         open(self.page, "w+").close()
-
+        
+    def __repr__(self):
+        return self.buffer.join("\n")
+        
     def commit(self): # My fancy way of letting the user empty and add the buffer to a file (Inspired by git)
         with open(self.page, "a+") as f:
             f.write(''.join(self.buffer))
@@ -35,7 +37,7 @@ class newpage: # The VERY base class in Ebuilder Ultra Core, This handles all th
     def __enter__(self):
         pass
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(self):
         self.final_commit()
         
 class EbuilderTextComponent: # A simple class used to define text components
@@ -68,4 +70,4 @@ class EbuilderTextComponent: # A simple class used to define text components
         self.style_it()
 
 header = EbuilderTextComponent("h1") # VERY SIMPLE COMPONENT DEFINITIONS
-paragraph = EbuilderTextComponent("p")
\ No newline at end of file
+paragraph = EbuilderTextComponent("p")
